@@ -20,8 +20,11 @@ from aqt.profiles import VideoDriver
 from aqt.qt import *
 from aqt.sync import sync_login
 from aqt.theme import Theme
+from aqt.url_schemes import show_url_schemes_dialog
 from aqt.utils import (
     HelpPage,
+    add_close_shortcut,
+    add_ellipsis_to_action_label,
     askUser,
     disable_help_button,
     is_win,
@@ -64,6 +67,7 @@ class Preferences(QDialog):
         self.setup_profile()
         self.setup_global()
         self.setup_configurable_answer_keys()
+        add_close_shortcut(self)
         self.show()
 
     def setup_configurable_answer_keys(self):
@@ -78,11 +82,14 @@ class Preferences(QDialog):
         )
         group = self.form.preferences_answer_keys
         group.setLayout(layout := QFormLayout())
+        tab_widget: QWidget = self.form.url_schemes
         for ease, label in ease_labels:
             layout.addRow(
                 label,
                 line_edit := QLineEdit(self.mw.pm.get_answer_key(ease) or ""),
             )
+            QWidget.setTabOrder(tab_widget, line_edit)
+            tab_widget = line_edit
             qconnect(
                 line_edit.textChanged,
                 functools.partial(self.mw.pm.set_answer_key, ease),
@@ -150,6 +157,9 @@ class Preferences(QDialog):
         form.monthly_backups.setValue(self.prefs.backups.monthly)
         form.minutes_between_backups.setValue(self.prefs.backups.minimum_interval_mins)
 
+        add_ellipsis_to_action_label(self.form.url_schemes)
+        qconnect(self.form.url_schemes.clicked, show_url_schemes_dialog)
+
     def update_collection(self, on_done: Callable[[], None]) -> None:
         form = self.form
 
